@@ -26,7 +26,7 @@ use JSON 'to_json';
 use Lemonldap::NG::Common::Conf::ReConstants;
 use Lemonldap::NG::Manager::Attributes;
 
-our $VERSION = '2.0.4';
+our $VERSION = '2.0.6';
 
 extends 'Lemonldap::NG::Common::Conf::Compact';
 
@@ -103,13 +103,30 @@ sub check {
         hdebug("  testNewConf() failed");
         return 0;
     }
+    my $separator = $self->newConf->{multiValuesSeparator} || '; ';
     hdebug("  tests succeed");
-    $self->compactConf( $self->newConf );
+    my %conf          = %{ $self->newConf() };
+    my %compactedConf = %{ $self->compactConf( $self->newConf ) };
+    my @removedKeys   = ();
     unless ( $self->confChanged ) {
         hdebug("  no change detected");
         $self->message('__confNotChanged__');
         return 0;
     }
+    unless ( $self->newConf->{dontCompactConf} ) {
+        foreach ( sort keys %conf ) {
+            push @removedKeys, $_ unless exists $compactedConf{$_};
+        }
+    }
+    push @{ $self->changes },
+      (
+        $self->{newConf}->{dontCompactConf}
+        ? { confCompacted => '0' }
+        : {
+            confCompacted => '1',
+            removedKeys   => join( $separator, @removedKeys )
+        }
+      );
     return 1;
 }
 
@@ -160,7 +177,7 @@ sub _scanNodes {
         hdebug("Looking to $name");
 
         # subnode
-        my $subNodes     = $leaf->{nodes} // $leaf->{_nodes};
+        my $subNodes     = $leaf->{nodes}      // $leaf->{_nodes};
         my $subNodesCond = $leaf->{nodes_cond} // $leaf->{_nodes_cond};
 
         ##################################
@@ -383,6 +400,7 @@ sub _scanNodes {
                     }
                     elsif ($h) {
                         hdebug('    opened');
+                        $self->confChanged(1);
                         $self->set( $target, $key, $leaf->{title},
                             $leaf->{data} );
                     }
@@ -451,6 +469,7 @@ sub _scanNodes {
                     }
                     elsif ($h) {
                         hdebug('    opened');
+                        $self->confChanged(1);
                         $self->set( $target, $key, $leaf->{title},
                             $leaf->{data} );
                     }
@@ -564,7 +583,7 @@ sub _scanNodes {
             hdebug('Application list subnode');
             use feature 'state';
             my @cats = split /\//, $1;
-            my $app = pop @cats;
+            my $app  = pop @cats;
             $self->newConf->{applicationList} //= {};
 
             # $cn is a pointer to the parent
@@ -587,6 +606,22 @@ sub _scanNodes {
                 $cmp = $cmp->{$cat};
             }
 
+            my $newapp = $app;
+
+         # Compute a nice name for new nodes, taking care of potential conflicts
+         # For some reason, the manager sends /nNaN sometimes
+            if ( $newapp =~ /^n(\d+|NaN)$/ ) {
+
+                # Remove all special characters
+                my $baseName = $leaf->{title} =~ s/\W//gr;
+                $baseName = lc $baseName;
+                $newapp   = $baseName;
+                my $cnt = 1;
+                while ( exists $cn->{$newapp} ) {
+                    $newapp = "${baseName}_" . $cnt++;
+                }
+            }
+
             # Create new category
             #
             # Note that this works because nodes are ordered so "cat/cat2/app"
@@ -594,11 +629,14 @@ sub _scanNodes {
             if ( $leaf->{type} eq 'menuCat' ) {
                 hdebug('  menu cat');
                 $knownCat->{__id}++;
-                my $s = $knownCat->{$app} = sprintf '%04d-cat',
-                  $knownCat->{__id};
-                $cn->{$s} = { catname => $leaf->{title}, type => 'category' };
+                $knownCat->{$app} = $newapp;
+                $cn->{$newapp}    = {
+                    catname => $leaf->{title},
+                    type    => 'category',
+                    order   => $knownCat->{__id}
+                };
                 unless ($cmp->{$app}
-                    and $cmp->{$app}->{catname} eq $cn->{$s}->{catname} )
+                    and $cmp->{$app}->{catname} eq $cn->{$newapp}->{catname} )
                 {
                     $self->confChanged(1);
                     push @{ $self->changes },
@@ -606,15 +644,17 @@ sub _scanNodes {
                         key => join(
                             ', ', 'applicationList', @path, $leaf->{title}
                         ),
-                        new => $cn->{$s}->{catname},
-                        old => ( $cn->{$s} ? $cn->{$s}->{catname} : undef )
+                        new => $cn->{$newapp}->{catname},
+                        old => (
+                            $cn->{$newapp} ? $cn->{$newapp}->{catname} : undef
+                        )
                       };
                 }
                 if ( ref $subNodes ) {
                     $self->_scanNodes($subNodes) or return 0;
                 }
                 my @listCatRef = keys %{ $cmp->{$app} };
-                my @listCatNew = keys %{ $cn->{$s} };
+                my @listCatNew = keys %{ $cn->{$newapp} };
 
                 # Check for deleted
                 unless ( @listCatRef == @listCatNew ) {
@@ -631,10 +671,12 @@ sub _scanNodes {
             else {
                 hdebug('  new app');
                 $knownCat->{__id}++;
-                my $name = sprintf( '%04d-app', $knownCat->{__id} );
-                $cn->{$name} =
-                  { type => 'application', options => $leaf->{data} };
-                $cn->{$name}->{options}->{name} = $leaf->{title};
+                $cn->{$newapp} = {
+                    type    => 'application',
+                    options => $leaf->{data},
+                    order   => $knownCat->{__id}
+                };
+                $cn->{$newapp}->{options}->{name} = $leaf->{title};
                 unless ( $cmp->{$app} ) {
                     $self->confChanged(1);
                     push @{ $self->changes },
@@ -644,9 +686,17 @@ sub _scanNodes {
                       };
                 }
                 else {
-                    foreach my $k ( keys %{ $cn->{$name}->{options} } ) {
+                    # Check for change in ordering
+                    if ( ( $cn->{$newapp}->{order} || 0 ) !=
+                        ( $cmp->{$newapp}->{order} || 0 ) )
+                    {
+                        $self->confChanged(1);
+                    }
+
+                    # Check for change in options
+                    foreach my $k ( keys %{ $cn->{$newapp}->{options} } ) {
                         unless ( $cmp->{$app}->{options}->{$k} eq
-                            $cn->{$name}->{options}->{$k} )
+                            $cn->{$newapp}->{options}->{$k} )
                         {
                             $self->confChanged(1);
                             push @{ $self->changes },
@@ -654,7 +704,7 @@ sub _scanNodes {
                                 key => join( ', ',
                                     'applicationList', @path,
                                     $leaf->{title},    $k ),
-                                new => $cn->{$name}->{options}->{$k},
+                                new => $cn->{$newapp}->{options}->{$k},
                                 old => $cmp->{$app}->{options}->{$k}
                               };
                         }
@@ -762,6 +812,26 @@ sub _scanNodes {
                     next;
                 }
 
+                # sfExtra: just to replace "over" key
+                if ( $name eq 'sfExtra' ) {
+                    hdebug('     sfExtra');
+                    $self->newConf->{$name} = {};
+                    foreach my $node ( @{ $leaf->{nodes} } ) {
+                        my $tmp;
+                        $tmp->{$_} = $node->{data}->{$_}
+                          foreach (qw(type rule logo label));
+                        $tmp->{over} = {};
+                        foreach ( @{ $node->{data}->{over} } ) {
+                            $tmp->{over}->{ $_->[0] } = $_->[1];
+                        }
+                        $self->newConf->{$name}->{ $node->{title} } = $tmp;
+                    }
+
+                    # TODO: check changes
+                    $self->confChanged(1);
+                    next;
+                }
+
                 $subNodes //= [];
                 my $count = 0;
                 my @old   = (
@@ -841,7 +911,7 @@ sub _scanNodes {
                 }
                 else {
                     @oldHosts = grep { $_ ne $host } @oldHosts;
-                    @oldKeys = keys %{ $self->refConf->{$name}->{$host} };
+                    @oldKeys  = keys %{ $self->refConf->{$name}->{$host} };
                 }
                 foreach my $prm ( @{ $getHost->{h} } ) {
                     $self->newConf->{$name}->{$host}->{ $prm->{k} } =
@@ -1070,14 +1140,14 @@ sub _unitTest {
                 or $attr->{type} =~ /Container$/ )
             {
                 my $keyMsg = $attr->{keyMsgFail} // $type->{keyMsgFail};
-                my $msg    = $attr->{msgFail} // $type->{msgFail};
+                my $msg    = $attr->{msgFail}    // $type->{msgFail};
                 $res = 0
                   unless (
                     $self->_execTest( {
                             keyTest    => $attr->{keyTest} // $type->{keyTest},
                             keyMsgFail => $attr->{keyMsgFail}
                               // $type->{keyMsgFail},
-                            test    => $attr->{test} // $type->{test},
+                            test    => $attr->{test}    // $type->{test},
                             msgFail => $attr->{msgFail} // $type->{msgFail},
                         },
                         $conf->{$key},
